# media_editing

# setup

```Bash
pip install media_editing
```

# Markdown_to_HTML.py

This script recursively converts Markdown files at a specified directory to HTML files, with options to include numbered sections, table of contents, CSS and to output commands only, not execute.

# images_to_video.py

This script converts a list of image files to a video with the options of specifying the image extension, a soundtrack file, an output filename and a framerate.

# text_to_QR_code.py

This script converts specified text to a QR code of specified scale and filepath and optionally displays the resulting QR code image using the default image viewer.

# vidgif.py

This script converts a video to an animated GIF, with the option to output commands only, not execute.
